AFRL labeling elements (sarpy.annotation.afrl_elements)
=======================================================

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    research
    collection_info
    subcollection_info
    image_info
    sensor_info
    fiducial_info
    object_info
    blocks
